@@ -23,12 +23,13 @@ class Composition : public Segmentation {
   Composition() = default;
 
   bool HasFinishedComposition() const;
-  Preedit GetPreedit(const string& full_input, size_t caret_pos,
+  Preedit GetPreedit(const string& full_input,
+                     size_t caret_pos,
                      const string& caret) const;
   string GetPrompt() const;
   string GetCommitText() const;
   string GetScriptText() const;
-  string GetDebugText() const;
+  RIME_API string GetDebugText() const;
   // Returns text of the last segment before the given position.
   string GetTextBefore(size_t pos) const;
 };
