@@ -21,8 +21,8 @@ class ConfigData {
 
   bool LoadFromStream(std::istream& stream);
   bool SaveToStream(std::ostream& stream);
-  bool LoadFromFile(const string& file_name, ConfigCompiler* compiler);
-  bool SaveToFile(const string& file_name);
+  bool LoadFromFile(const path& file_path, ConfigCompiler* compiler);
+  bool SaveToFile(const path& file_path);
   bool TraverseWrite(const string& path, an<ConfigItem> item);
   an<ConfigItem> Traverse(const string& path);
 
@@ -34,7 +34,7 @@ class ConfigData {
                                  const string& key,
                                  bool read_only = false);
 
-  const string& file_name() const { return file_name_; }
+  const path& file_path() const { return file_path_; }
   bool modified() const { return modified_; }
   void set_modified() { modified_ = true; }
   void set_auto_save(bool auto_save) { auto_save_ = auto_save; }
@@ -42,7 +42,7 @@ class ConfigData {
   an<ConfigItem> root;
 
  protected:
-  string file_name_;
+  path file_path_;
   bool modified_ = false;
   bool auto_save_ = false;
 };
