@@ -121,6 +121,27 @@ bool Context::Select(size_t index) {
   return false;
 }
 
+bool Context::Highlight(size_t index) {
+  if (composition_.empty() || !composition_.back().menu)
+    return false;
+  Segment& seg(composition_.back());
+  size_t new_index = index;
+  size_t candidate_count = seg.menu->Prepare(index + 1);
+  if (index >= candidate_count) {
+    DLOG(INFO) << "selection index exceeds candidate pool, fallback to last";
+    new_index = candidate_count - 1;
+  }
+  size_t previous_index = seg.selected_index;
+  if (previous_index == new_index) {
+    DLOG(INFO) << "selection has not changed, currently at " << new_index;
+    return false;
+  }
+  seg.selected_index = new_index;
+  update_notifier_(this);
+  DLOG(INFO) << "selection changed from: " << previous_index << " to: " << new_index;
+  return true;
+}
+
 bool Context::DeleteCandidate(
     function<an<Candidate>(Segment& seg)> get_candidate) {
   if (composition_.empty())
