@@ -5,9 +5,8 @@
 // 2011-11-02 GONG Chen <chen.sst@gmail.com>
 //
 #include <cstdlib>
+#include <sstream>
 #include <boost/algorithm/string.hpp>
-#include <boost/format.hpp>
-#include <boost/lexical_cast.hpp>
 #include <rime/service.h>
 #include <rime/algo/dynamics.h>
 #include <rime/dict/text_db.h>
@@ -20,8 +19,9 @@ UserDbValue::UserDbValue(const string& value) {
 }
 
 string UserDbValue::Pack() const {
-  return boost::str(boost::format("c=%1% d=%2% t=%3%") %
-                    commits % dee % tick);
+  std::ostringstream packed;
+  packed << "c=" << commits << " d=" << dee << " t=" << tick;
+  return packed.str();
 }
 
 bool UserDbValue::Unpack(const string& value) {
@@ -35,18 +35,15 @@ bool UserDbValue::Unpack(const string& value) {
     string v(k_eq_v.substr(eq + 1));
     try {
       if (k == "c") {
-        commits = boost::lexical_cast<int>(v);
+        commits = std::stoi(v);
+      } else if (k == "d") {
+        dee = (std::min)(10000.0, std::stod(v));
+      } else if (k == "t") {
+        tick = std::stoul(v);
       }
-      else if (k == "d") {
-        dee = (std::min)(10000.0, boost::lexical_cast<double>(v));
-      }
-      else if (k == "t") {
-        tick = boost::lexical_cast<TickCount>(v);
-      }
-    }
-    catch (...) {
-      LOG(ERROR) << "failed in parsing key-value from userdb entry '"
-                 << k_eq_v << "'.";
+    } catch (...) {
+      LOG(ERROR) << "failed in parsing key-value from userdb entry '" << k_eq_v
+                 << "'.";
       return false;
     }
   }
@@ -66,11 +63,8 @@ string UserDb::snapshot_extension() {
 
 // key ::= code <space> <Tab> phrase
 
-static bool userdb_entry_parser(const Tsv& row,
-                                string* key,
-                                string* value) {
-  if (row.size() < 2 ||
-      row[0].empty() || row[1].empty()) {
+static bool userdb_entry_parser(const Tsv& row, string* key, string* value) {
+  if (row.size() < 2 || row[0].empty() || row[1].empty()) {
     return false;
   }
   string code(row[0]);
@@ -89,61 +83,56 @@ static bool userdb_entry_formatter(const string& key,
                                    const string& value,
                                    Tsv* tsv) {
   Tsv& row(*tsv);
-  boost::algorithm::split(row, key,
-                          boost::algorithm::is_any_of("\t"));
-  if (row.size() != 2 ||
-      row[0].empty() || row[1].empty())
+  boost::algorithm::split(row, key, boost::algorithm::is_any_of("\t"));
+  if (row.size() != 2 || row[0].empty() || row[1].empty())
     return false;
   row.push_back(value);
   return true;
 }
 
 static TextFormat plain_userdb_format = {
-  userdb_entry_parser,
-  userdb_entry_formatter,
-  "Rime user dictionary",
+    userdb_entry_parser,
+    userdb_entry_formatter,
+    "Rime user dictionary",
 };
 
 template <>
-UserDbWrapper<TextDb>::UserDbWrapper(const string& file_name,
-                                     const string& db_name)
-    : TextDb(file_name, db_name, "userdb", plain_userdb_format) {
-}
+RIME_API UserDbWrapper<TextDb>::UserDbWrapper(const path& file_path,
+                                              const string& db_name)
+    : TextDb(file_path, db_name, "userdb", plain_userdb_format) {}
 
 bool UserDbHelper::UpdateUserInfo() {
   Deployer& deployer(Service::instance().deployer());
   return db_->MetaUpdate("/user_id", deployer.user_id);
 }
 
-bool UserDbHelper::IsUniformFormat(const string& file_name) {
-  return boost::ends_with(file_name, plain_userdb_extension);
+bool UserDbHelper::IsUniformFormat(const path& file_path) {
+  return boost::ends_with(file_path.filename().u8string(),
+                          plain_userdb_extension);
 }
 
-bool UserDbHelper::UniformBackup(const string& snapshot_file) {
-  LOG(INFO) << "backing up userdb '" << db_->name() << "' to "
-            << snapshot_file;
+bool UserDbHelper::UniformBackup(const path& snapshot_file) {
+  LOG(INFO) << "backing up userdb '" << db_->name() << "' to " << snapshot_file;
   TsvWriter writer(snapshot_file, plain_userdb_format.formatter);
   writer.file_description = plain_userdb_format.file_description;
   DbSource source(db_);
   try {
     writer << source;
-  }
-  catch (std::exception& ex) {
+  } catch (std::exception& ex) {
     LOG(ERROR) << ex.what();
     return false;
   }
   return true;
 }
 
-bool UserDbHelper::UniformRestore(const string& snapshot_file) {
+bool UserDbHelper::UniformRestore(const path& snapshot_file) {
   LOG(INFO) << "restoring userdb '" << db_->name() << "' from "
             << snapshot_file;
   TsvReader reader(snapshot_file, plain_userdb_format.parser);
   DbSink sink(db_);
   try {
     reader >> sink;
-  }
-  catch (std::exception& ex) {
+  } catch (std::exception& ex) {
     LOG(ERROR) << ex.what();
     return false;
   }
@@ -183,9 +172,8 @@ static TickCount get_tick_count(Db* db) {
   string tick;
   if (db && db->MetaFetch("/tick", &tick)) {
     try {
-      return boost::lexical_cast<TickCount>(tick);
-    }
-    catch (...) {
+      return std::stoul(tick);
+    } catch (...) {
     }
   }
   return 1;
@@ -204,17 +192,17 @@ UserDbMerger::~UserDbMerger() {
 bool UserDbMerger::MetaPut(const string& key, const string& value) {
   if (key == "/tick") {
     try {
-      their_tick_ = boost::lexical_cast<TickCount>(value);
+      their_tick_ = std::stoul(value);
       max_tick_ = (std::max)(our_tick_, their_tick_);
-    }
-    catch (...) {
+    } catch (...) {
     }
   }
   return true;
 }
 
 bool UserDbMerger::Put(const string& key, const string& value) {
-  if (!db_) return false;
+  if (!db_)
+    return false;
   UserDbValue v(value);
   if (v.tick < their_tick_) {
     v.dee = algo::formula_d(0, (double)their_tick_, v.dee, (double)v.tick);
@@ -228,7 +216,7 @@ bool UserDbMerger::Put(const string& key, const string& value) {
     o.dee = algo::formula_d(0, (double)our_tick_, o.dee, (double)o.tick);
   }
   if (std::abs(o.commits) < std::abs(v.commits))
-      o.commits = v.commits;
+    o.commits = v.commits;
   o.dee = (std::max)(o.dee, v.dee);
   o.tick = max_tick_;
   return db_->Update(key, o.Pack()) && ++merged_entries_;
@@ -239,28 +227,26 @@ void UserDbMerger::CloseMerge() {
     return;
   Deployer& deployer(Service::instance().deployer());
   try {
-    db_->MetaUpdate("/tick", boost::lexical_cast<string>(max_tick_));
+    db_->MetaUpdate("/tick", std::to_string(max_tick_));
     db_->MetaUpdate("/user_id", deployer.user_id);
-  }
-  catch (...) {
+  } catch (...) {
     LOG(ERROR) << "failed to update tick count.";
     return;
   }
-  LOG(INFO) << "total " << merged_entries_ << " entries merged, tick = "
-            << max_tick_;
+  LOG(INFO) << "total " << merged_entries_
+            << " entries merged, tick = " << max_tick_;
   merged_entries_ = 0;
 }
 
-UserDbImporter::UserDbImporter(Db* db)
-    : db_(db) {
-}
+UserDbImporter::UserDbImporter(Db* db) : db_(db) {}
 
 bool UserDbImporter::MetaPut(const string& key, const string& value) {
   return true;
 }
 
 bool UserDbImporter::Put(const string& key, const string& value) {
-  if (!db_) return false;
+  if (!db_)
+    return false;
   UserDbValue v(value);
   UserDbValue o;
   string old_value;
@@ -270,8 +256,7 @@ bool UserDbImporter::Put(const string& key, const string& value) {
   if (v.commits > 0) {
     o.commits = (std::max)(o.commits, v.commits);
     o.dee = (std::max)(o.dee, v.dee);
-  }
-  else if (v.commits < 0) {  // mark as deleted
+  } else if (v.commits < 0) {  // mark as deleted
     o.commits = (std::min)(v.commits, -std::abs(o.commits));
   }
   return db_->Update(key, o.Pack());
