@@ -19,7 +19,7 @@ class Context;
 
 class Engine : public Messenger {
  public:
-  using CommitSink = signal<void (const string& commit_text)>;
+  using CommitSink = signal<void(const string& commit_text)>;
 
   virtual ~Engine();
   virtual bool ProcessKey(const KeyEvent& key_event) { return false; }
@@ -31,12 +31,8 @@ class Engine : public Messenger {
   Context* context() const { return context_.get(); }
   CommitSink& sink() { return sink_; }
 
-  Engine* active_engine() {
-    return active_engine_ ? active_engine_ : this;
-  }
-  void set_active_engine(Engine* engine = nullptr) {
-    active_engine_ = engine;
-  }
+  Engine* active_engine() { return active_engine_ ? active_engine_ : this; }
+  void set_active_engine(Engine* engine = nullptr) { active_engine_ = engine; }
 
   RIME_API static Engine* Create();
 
