@@ -8,6 +8,7 @@
 //
 #include <algorithm>
 #include <stack>
+#include <cmath>
 #include <boost/algorithm/string/join.hpp>
 #include <boost/range/adaptor/reversed.hpp>
 #include <rime/composition.h>
@@ -25,9 +26,8 @@
 #include <rime/gear/script_translator.h>
 #include <rime/gear/translator_commons.h>
 
-
-//static const char* quote_left = "\xef\xbc\x88";
-//static const char* quote_right = "\xef\xbc\x89";
+// static const char* quote_left = "\xef\xbc\x88";
+// static const char* quote_right = "\xef\xbc\x89";
 
 namespace rime {
 
@@ -37,13 +37,17 @@ struct SyllabifyTask {
   const Code& code;
   const SyllableGraph& graph;
   size_t target_pos;
-  function<void (SyllabifyTask* task, size_t depth,
-                      size_t current_pos, size_t next_pos)> push;
-  function<void (SyllabifyTask* task, size_t depth)> pop;
+  function<void(SyllabifyTask* task,
+                size_t depth,
+                size_t current_pos,
+                size_t next_pos)>
+      push;
+  function<void(SyllabifyTask* task, size_t depth)> pop;
 };
 
 static bool syllabify_dfs(SyllabifyTask* task,
-                          size_t depth, size_t current_pos) {
+                          size_t depth,
+                          size_t current_pos) {
   if (depth == task->code.size()) {
     return current_pos == task->target_pos;
   }
@@ -75,7 +79,9 @@ class ScriptSyllabifier : public PhraseSyllabifier {
                     Corrector* corrector,
                     const string& input,
                     size_t start)
-      : translator_(translator), input_(input), start_(start),
+      : translator_(translator),
+        input_(input),
+        start_(start),
         syllabifier_(translator->delimiters(),
                      translator->enable_completion(),
                      translator->strict_spelling()) {
@@ -110,8 +116,8 @@ class ScriptTranslation : public Translation {
       : translator_(translator),
         poet_(poet),
         start_(start),
-        syllabifier_(New<ScriptSyllabifier>(
-            translator, corrector, input, start)),
+        syllabifier_(
+            New<ScriptSyllabifier>(translator, corrector, input, start)),
         enable_correction_(corrector) {
     set_exhausted(true);
   }
@@ -151,9 +157,7 @@ class ScriptTranslation : public Translation {
 // ScriptTranslator implementation
 
 ScriptTranslator::ScriptTranslator(const Ticket& ticket)
-    : Translator(ticket),
-      Memory(ticket),
-      TranslatorOptions(ticket) {
+    : Translator(ticket), Memory(ticket), TranslatorOptions(ticket) {
   if (!engine_)
     return;
   if (Config* config = engine_->schema()->config()) {
@@ -177,23 +181,19 @@ an<Translation> ScriptTranslator::Query(const string& input,
     return nullptr;
   if (!segment.HasTag(tag_))
     return nullptr;
-  DLOG(INFO) << "input = '" << input
-             << "', [" << segment.start << ", " << segment.end << ")";
+  DLOG(INFO) << "input = '" << input << "', [" << segment.start << ", "
+             << segment.end << ")";
 
   FinishSession();
 
-  bool enable_user_dict = user_dict_ && user_dict_->loaded() &&
-      !IsUserDictDisabledFor(input);
+  bool enable_user_dict =
+      user_dict_ && user_dict_->loaded() && !IsUserDictDisabledFor(input);
 
   // the translator should survive translations it creates
-  auto result = New<ScriptTranslation>(this,
-                                       corrector_.get(),
-                                       poet_.get(),
-                                       input,
-                                       segment.start);
-  if (!result ||
-      !result->Evaluate(dict_.get(),
-                        enable_user_dict ? user_dict_.get() : NULL)) {
+  auto result = New<ScriptTranslation>(this, corrector_.get(), poet_.get(),
+                                       input, segment.start);
+  if (!result || !result->Evaluate(
+                     dict_.get(), enable_user_dict ? user_dict_.get() : NULL)) {
     return nullptr;
   }
   auto deduped = New<DistinctTranslation>(result);
@@ -214,16 +214,15 @@ string ScriptTranslator::Spell(const Code& code) {
   vector<string> syllables;
   if (!dict_ || !dict_->Decode(code, &syllables) || syllables.empty())
     return result;
-  result =  boost::algorithm::join(syllables,
-                                   string(1, delimiters_.at(0)));
+  result = boost::algorithm::join(syllables, string(1, delimiters_.at(0)));
   comment_formatter_.Apply(&result);
   return result;
 }
 
 string ScriptTranslator::GetPrecedingText(size_t start) const {
-  return !contextual_suggestions_ ? string() :
-      start > 0 ? engine_->context()->composition().GetTextBefore(start) :
-      engine_->context()->commit_history().latest_text();
+  return !contextual_suggestions_ ? string()
+         : start > 0 ? engine_->context()->composition().GetTextBefore(start)
+                     : engine_->context()->commit_history().latest_text();
 }
 
 bool ScriptTranslator::Memorize(const CommitEntry& commit_entry) {
@@ -254,17 +253,10 @@ Spans ScriptSyllabifier::Syllabify(const Phrase* phrase) {
   vector<size_t> vertices;
   vertices.push_back(start_);
   SyllabifyTask task{
-    phrase->code(),
-    syllable_graph_,
-    phrase->end() - start_,
-    [&](SyllabifyTask* task, size_t depth,
-        size_t current_pos, size_t next_pos) {
-      vertices.push_back(start_ + next_pos);
-    },
-    [&](SyllabifyTask* task, size_t depth) {
-      vertices.pop_back();
-    }
-  };
+      phrase->code(), syllable_graph_, phrase->end() - start_,
+      [&](SyllabifyTask* task, size_t depth, size_t current_pos,
+          size_t next_pos) { vertices.push_back(start_ + next_pos); },
+      [&](SyllabifyTask* task, size_t depth) { vertices.pop_back(); }};
   if (syllabify_dfs(&task, 0, phrase->start() - start_)) {
     result.set_vertices(std::move(vertices));
   }
@@ -272,40 +264,36 @@ Spans ScriptSyllabifier::Syllabify(const Phrase* phrase) {
 }
 
 size_t ScriptSyllabifier::BuildSyllableGraph(Prism& prism) {
-  return (size_t)syllabifier_.BuildSyllableGraph(input_,
-                                                 prism,
+  return (size_t)syllabifier_.BuildSyllableGraph(input_, prism,
                                                  &syllable_graph_);
 }
 
-bool ScriptSyllabifier::IsCandidateCorrection(const rime::Phrase &cand) const {
+bool ScriptSyllabifier::IsCandidateCorrection(const rime::Phrase& cand) const {
   std::stack<bool> results;
-  // Perform DFS on syllable graph to find whether this candidate is a correction
-  SyllabifyTask task {
-    cand.code(),
-    syllable_graph_,
-    cand.end() - start_,
-    [&](SyllabifyTask* task, size_t depth,
-        size_t current_pos, size_t next_pos) {
-      auto id = cand.code()[depth];
-      auto it_s = syllable_graph_.edges.find(current_pos);
-      // C++ prohibit operator [] of const map
-      // if (syllable_graph_.edges[current_pos][next_pos][id].type == kCorrection)
-      if (it_s != syllable_graph_.edges.end()) {
-        auto it_e = it_s->second.find(next_pos);
-        if (it_e != it_s->second.end()) {
-          auto it_type = it_e->second.find(id);
-          if (it_type != it_e->second.end()) {
-            results.push(it_type->second.is_correction);
-            return;
-          }
-        }
-      }
-      results.push(false);
-    },
-    [&](SyllabifyTask* task, size_t depth) {
-      results.pop();
-    }
-  };
+  // Perform DFS on syllable graph to find whether this candidate is a
+  // correction
+  SyllabifyTask task{cand.code(), syllable_graph_, cand.end() - start_,
+                     [&](SyllabifyTask* task, size_t depth, size_t current_pos,
+                         size_t next_pos) {
+                       auto id = cand.code()[depth];
+                       auto it_s = syllable_graph_.edges.find(current_pos);
+                       // C++ prohibit operator [] of const map
+                       // if
+                       // (syllable_graph_.edges[current_pos][next_pos][id].type
+                       // == kCorrection)
+                       if (it_s != syllable_graph_.edges.end()) {
+                         auto it_e = it_s->second.find(next_pos);
+                         if (it_e != it_s->second.end()) {
+                           auto it_type = it_e->second.find(id);
+                           if (it_type != it_e->second.end()) {
+                             results.push(it_type->second.is_correction);
+                             return;
+                           }
+                         }
+                       }
+                       results.push(false);
+                     },
+                     [&](SyllabifyTask* task, size_t depth) { results.pop(); }};
   if (syllabify_dfs(&task, 0, cand.start() - start_)) {
     for (; !results.empty(); results.pop()) {
       if (results.top())
@@ -319,29 +307,25 @@ string ScriptSyllabifier::GetPreeditString(const Phrase& cand) const {
   const auto& delimiters = translator_->delimiters();
   std::stack<size_t> lengths;
   string output;
-  SyllabifyTask task{
-    cand.code(),
-    syllable_graph_,
-    cand.end() - start_,
-    [&](SyllabifyTask* task, size_t depth,
-        size_t current_pos, size_t next_pos) {
-      size_t len = output.length();
-      if (depth > 0 && len > 0 &&
-          delimiters.find(output[len - 1]) == string::npos) {
-        output += delimiters.at(0);
-      }
-      output += input_.substr(current_pos, next_pos - current_pos);
-      lengths.push(len);
-    },
-    [&](SyllabifyTask* task, size_t depth) {
-      output.resize(lengths.top());
-      lengths.pop();
-    }
-  };
+  SyllabifyTask task{cand.code(), syllable_graph_, cand.end() - start_,
+                     [&](SyllabifyTask* task, size_t depth, size_t current_pos,
+                         size_t next_pos) {
+                       size_t len = output.length();
+                       if (depth > 0 && len > 0 &&
+                           delimiters.find(output[len - 1]) == string::npos) {
+                         output += delimiters.at(0);
+                       }
+                       output +=
+                           input_.substr(current_pos, next_pos - current_pos);
+                       lengths.push(len);
+                     },
+                     [&](SyllabifyTask* task, size_t depth) {
+                       output.resize(lengths.top());
+                       lengths.pop();
+                     }};
   if (syllabify_dfs(&task, 0, cand.start() - start_)) {
     return translator_->FormatPreedit(output);
-  }
-  else {
+  } else {
     return string();
   }
 }
@@ -408,8 +392,7 @@ bool ScriptTranslation::Next() {
       if (!uter.Next()) {
         ++user_phrase_iter_;
       }
-    }
-    else if (phrase_code_length > 0) {
+    } else if (phrase_code_length > 0) {
       DictEntryIterator& iter(phrase_iter_->second);
       if (!iter.Next()) {
         ++phrase_iter_;
@@ -422,9 +405,8 @@ bool ScriptTranslation::Next() {
       }
       is_correction = syllabifier_->IsCandidateCorrection(*candidate_);
     }
-  } while ( // limit the number of correction candidates
-      enable_correction_ &&
-      is_correction &&
+  } while (  // limit the number of correction candidates
+      enable_correction_ && is_correction &&
       correction_count_ > max_corrections_);
   if (is_correction) {
     ++correction_count_;
@@ -435,7 +417,7 @@ bool ScriptTranslation::Next() {
 bool ScriptTranslation::IsNormalSpelling() const {
   const auto& syllable_graph = syllabifier_->syllable_graph();
   return !syllable_graph.vertices.empty() &&
-      (syllable_graph.vertices.rbegin()->second == kNormalSpelling);
+         (syllable_graph.vertices.rbegin()->second == kNormalSpelling);
 }
 
 an<Candidate> ScriptTranslation::Peek() {
@@ -448,10 +430,9 @@ an<Candidate> ScriptTranslation::Peek() {
   }
   if (candidate_->comment().empty()) {
     auto spelling = syllabifier_->GetOriginalSpelling(*candidate_);
-    if (!spelling.empty() &&
-        (translator_->always_show_comments() ||
-          spelling != candidate_->preedit())) {
-      candidate_->set_comment(/*quote_left + */spelling/* + quote_right*/);
+    if (!spelling.empty() && (translator_->always_show_comments() ||
+                              spelling != candidate_->preedit())) {
+      candidate_->set_comment(/*quote_left + */ spelling /* + quote_right*/);
     }
   }
   candidate_->set_syllabifier(syllabifier_);
@@ -482,27 +463,18 @@ void ScriptTranslation::PrepareCandidate() {
     const auto& entry = uter.Peek();
     DLOG(INFO) << "user phrase '" << entry->text
                << "', code length: " << user_phrase_code_length;
-    cand = New<Phrase>(translator_->language(),
-                       "user_phrase",
-                       start_,
-                       start_ + user_phrase_code_length,
-                       entry);
-    cand->set_quality(exp(entry->weight) +
-                      translator_->initial_quality() +
+    cand = New<Phrase>(translator_->language(), "user_phrase", start_,
+                       start_ + user_phrase_code_length, entry);
+    cand->set_quality(std::exp(entry->weight) + translator_->initial_quality() +
                       (IsNormalSpelling() ? 0.5 : -0.5));
-  }
-  else if (phrase_code_length > 0) {
+  } else if (phrase_code_length > 0) {
     DictEntryIterator& iter = phrase_iter_->second;
     const auto& entry = iter.Peek();
     DLOG(INFO) << "phrase '" << entry->text
                << "', code length: " << phrase_code_length;
-    cand = New<Phrase>(translator_->language(),
-                       "phrase",
-                       start_,
-                       start_ + phrase_code_length,
-                       entry);
-    cand->set_quality(exp(entry->weight) +
-                      translator_->initial_quality() +
+    cand = New<Phrase>(translator_->language(), "phrase", start_,
+                       start_ + phrase_code_length, entry);
+    cand->set_quality(std::exp(entry->weight) + translator_->initial_quality() +
                       (IsNormalSpelling() ? 0 : -1));
   }
   candidate_ = cand;
@@ -540,17 +512,15 @@ an<Sentence> ScriptTranslation::MakeSentence(Dictionary* dict,
     auto& same_start_pos = graph[x.first];
     if (user_dict) {
       EnrollEntries(same_start_pos,
-                    user_dict->Lookup(syllable_graph,
-                                      x.first,
+                    user_dict->Lookup(syllable_graph, x.first,
                                       kMaxSyllablesForUserPhraseQuery));
     }
     // merge lookup results
     EnrollEntries(same_start_pos, dict->Lookup(syllable_graph, x.first));
   }
   if (auto sentence =
-      poet_->MakeSentence(graph,
-                          syllable_graph.interpreted_length,
-                          translator_->GetPrecedingText(start_))) {
+          poet_->MakeSentence(graph, syllable_graph.interpreted_length,
+                              translator_->GetPrecedingText(start_))) {
     sentence->Offset(start_);
     sentence->set_syllabifier(syllabifier_);
     return sentence;
