@@ -9,17 +9,15 @@
 
 namespace rime {
 
-Schema::Schema()
-    : schema_id_(".default") {
+Schema::Schema() : schema_id_(".default") {
   config_.reset(Config::Require("config")->Create("default"));
   FetchUsefulConfigItems();
 }
 
-Schema::Schema(const string& schema_id)
-    : schema_id_(schema_id) {
-  config_.reset(boost::starts_with(schema_id_, L".") ?
-                Config::Require("config")->Create(schema_id.substr(1)) :
-                Config::Require("schema")->Create(schema_id));
+Schema::Schema(const string& schema_id) : schema_id_(schema_id) {
+  config_.reset(boost::starts_with(schema_id_, L".")
+                    ? Config::Require("config")->Create(schema_id.substr(1))
+                    : Config::Require("schema")->Create(schema_id));
   FetchUsefulConfigItems();
 }
 
@@ -32,6 +30,9 @@ void Schema::FetchUsefulConfigItems() {
     schema_name_ = schema_id_;
   }
   config_->GetInt("menu/page_size", &page_size_);
+  if (page_size_ < 1) {
+    page_size_ = 5;
+  }
   config_->GetString("menu/alternative_select_keys", &select_keys_);
   config_->GetBool("menu/page_down_cycle", &page_down_cycle_);
 }
