@@ -94,6 +94,7 @@ typedef struct rime_traits_t {
   int min_log_level;
   /*! Directory of log files.
    *  Value is passed to Glog library using FLAGS_log_dir variable.
+   *  NULL means temporary directory, and "" means only writing to stderr.
    */
   const char* log_dir;
   //! prebuilt data directory. defaults to ${shared_data_dir}/build
@@ -386,6 +387,7 @@ RIME_API Bool RimeConfigUpdateSignature(RimeConfig* config, const char* signer);
 RIME_API Bool RimeSimulateKeySequence(RimeSessionId session_id,
                                       const char* key_sequence);
 
+RIME_API Bool RimeSetInput(RimeSessionId session_id, const char* input);
 // Module
 
 /*!
@@ -411,9 +413,13 @@ RIME_API RimeModule* RimeFindModule(const char* module_name);
 //! Run a registered task
 RIME_API Bool RimeRunTask(const char* task_name);
 
+//! \deprecated use RimeApi::get_shared_data_dir_s instead.
 RIME_API const char* RimeGetSharedDataDir(void);
+//! \deprecated use RimeApi::get_user_data_dir_s instead.
 RIME_API const char* RimeGetUserDataDir(void);
+//! \deprecated use RimeApi::get_sync_dir_s instead.
 RIME_API const char* RimeGetSyncDir(void);
+
 RIME_API const char* RimeGetUserId(void);
 
 /*! The API structure
@@ -541,9 +547,14 @@ typedef struct rime_api_t {
   RimeModule* (*find_module)(const char* module_name);
 
   Bool (*run_task)(const char* task_name);
+
+  //! \deprecated use get_shared_data_dir_s instead.
   const char* (*get_shared_data_dir)(void);
+  //! \deprecated use get_user_data_dir_s instead.
   const char* (*get_user_data_dir)(void);
+  //! \deprecated use get_sync_dir_s instead.
   const char* (*get_sync_dir)(void);
+
   const char* (*get_user_id)(void);
   void (*get_user_data_sync_dir)(char* dir, size_t buffer_size);
 
@@ -616,11 +627,13 @@ typedef struct rime_api_t {
                                     int index);
 
   //! prebuilt data directory.
+  //! \deprecated use get_prebuilt_data_dir_s instead.
   const char* (*get_prebuilt_data_dir)(void);
   //! staging directory, stores data files deployed to a Rime client.
+  //! \deprecated use get_staging_dir_s instead.
   const char* (*get_staging_dir)(void);
 
-  //! Deprecated: for capnproto API, use "proto" module from librime-proto
+  //! \deprecated for capnproto API, use "proto" module from librime-proto
   //! plugin.
   void (*commit_proto)(RimeSessionId session_id,
                        RIME_PROTO_BUILDER* commit_builder);
@@ -643,6 +656,21 @@ typedef struct rime_api_t {
                                                  const char* option_name,
                                                  Bool state,
                                                  Bool abbreviated);
+
+  Bool (*set_input)(RimeSessionId session_id, const char* input);
+
+  void (*get_shared_data_dir_s)(char* dir, size_t buffer_size);
+  void (*get_user_data_dir_s)(char* dir, size_t buffer_size);
+  void (*get_prebuilt_data_dir_s)(char* dir, size_t buffer_size);
+  void (*get_staging_dir_s)(char* dir, size_t buffer_size);
+  void (*get_sync_dir_s)(char* dir, size_t buffer_size);
+
+  //! highlight a selection without committing
+  Bool (*highlight_candidate)(RimeSessionId session_id, size_t index);
+  //! highlight a selection without committing
+  Bool (*highlight_candidate_on_current_page)(RimeSessionId session_id, size_t index);
+
+  Bool (*change_page)(RimeSessionId session_id, Bool backward);
 } RimeApi;
 
 //! API entry
